Crate codex_login

Crate codex_login 

Re-exports

pub use auth::AgentIdentityAuthPolicy;
pub use auth::AuthConfig;
pub use auth::AuthDotJson;
pub use auth::AuthHeaders;
pub use auth::AuthManager;
pub use auth::AuthManagerConfig;
pub use auth::CLIENT_ID;
pub use auth::CLIENT_ID_OVERRIDE_ENV_VAR;
pub use auth::CODEX_ACCESS_TOKEN_ENV_VAR;
pub use auth::CODEX_API_KEY_ENV_VAR;
pub use auth::CodexAuth;
pub use auth::ExternalAuth;
pub use auth::ExternalAuthFuture;
pub use auth::ExternalAuthRefreshContext;
pub use auth::ExternalAuthRefreshReason;
pub use auth::OPENAI_API_KEY_ENV_VAR;
pub use auth::REFRESH_TOKEN_URL_OVERRIDE_ENV_VAR;
pub use auth::REVOKE_TOKEN_URL_OVERRIDE_ENV_VAR;
pub use auth::RefreshTokenError;
pub use auth::UnauthorizedRecovery;
pub use auth::default_client;
pub use auth::enforce_login_restrictions;
pub use auth::load_auth_dot_json;
pub use auth::login_with_access_token;
pub use auth::login_with_api_key;
pub use auth::login_with_bedrock_api_key;
pub use auth::logout;
pub use auth::logout_with_revoke;
pub use auth::oauth_client_id;
pub use auth::read_codex_access_token_from_env;
pub use auth::read_openai_api_key_from_env;
pub use auth::save_auth;
pub use auth_env_telemetry::AuthEnvTelemetry;
pub use auth_env_telemetry::collect_auth_env_telemetry;
pub use token_data::TokenData;

Modules

auth
auth_env_telemetry
test_support
Test-only helpers exposed for cross-crate integration tests.
token_data

Structs

AuthRouteConfig
Auth-layer adapter around client-owned proxy policy.
DeviceCode
LoginServer
Handle for a running login callback server.
ServerOptions
Options for launching the local login callback server.
ShutdownHandle
Handle used to signal the login server loop to exit.

Enums

AuthCredentialsStoreMode
Determine where Codex should store CLI auth credentials.
AuthKeyringBackendKind
Determine how auth credentials should use keyring-backed storage.
BuildLoginHttpClientError
Describes why a transport using shared custom CA support could not be constructed.
LoginSuccessPage
LoginSuccessPageBrand

Constants

CODEX_OPEN_APP_URL

Functions

complete_device_code_login
request_device_code
run_device_code_login
run_login_server
Starts a local callback server and returns the browser auth URL.