pub enum AgentIdentityAuthPolicy {
JwtOnly,
ChatGptAuth,
}Expand description
Policy for resolving Agent Identity auth from a broader Codex auth snapshot.
Variants
JwtOnly
Use Agent Identity auth only when the current auth is already Agent Identity.
ChatGptAuth
Allow managed ChatGPT auth to register or reuse Agent Identity auth.