pub enum AuthKeyringBackendKind {
Direct,
Secrets,
}Expand description
Determine how auth credentials should use keyring-backed storage.
Variants
Direct
Store the serialized auth payload directly in the OS keyring.
Secrets
Store auth payloads in the local encrypted secrets file, with the file key in the OS keyring.