Default Codex HTTP client: shared User-Agent, originator, optional residency header, and
HttpClient construction.
Use crate::default_client or [codex_login::default_client] from other crates in this
workspace.
Structs
Enums
Constants
Statics
- USER_
AGENT_ SUFFIX - Set this to add a suffix to the User-Agent string.
Functions
- add_
originator_ header - Adds a valid, non-default thread originator override to request headers.
- create_
client - Create an HTTP client with default
originatorandUser-Agentheaders set. - create_
client_ for_ route - Builds the default Codex HTTP client for a concrete outbound route.
- create_
client_ for_ route_ async - Builds the default Codex HTTP client for a concrete outbound route without blocking the async runtime worker that initiated the request.
- create_
client_ without_ request_ logging - Create the default HTTP client without request URL or response-header diagnostics.
- default_
headers - get_
codex_ user_ agent - is_
first_ party_ chat_ originator - is_
first_ party_ originator - originator
- set_
default_ client_ residency_ requirement - set_
default_ originator